@@ -4,8 +4,8 @@ use Moo;
 with 'Search::Elasticsearch::Client::0_90::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 
-our $VERSION='5.02';
-use Search::Elasticsearch 5.02 ();
+our $VERSION='6.80';
+use Search::Elasticsearch 6.00 ();
 
 use Search::Elasticsearch::Util qw(parse_params is_compat);
 use namespace::clean;
@@ -107,7 +107,7 @@ Search::Elasticsearch::Client::0_90::Direct - Thin client with full support for
 
 =head1 VERSION
 
-version 5.02
+version 6.80
 
 =head1 SYNOPSIS
 
@@ -1048,11 +1048,11 @@ for more information.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
